package net.sf.jsequnit.diagram;

import java.io.IOException;
import java.util.Map;

import net.sf.jsequnit.junit.SingleTestMethodJUnit;

import com.sun.jdi.VirtualMachine;
import com.sun.jdi.connect.Connector.Argument;
import com.sun.jdi.connect.Connector.StringArgument;
import com.sun.jdi.connect.IllegalConnectorArgumentsException;
import com.sun.jdi.connect.LaunchingConnector;
import com.sun.jdi.connect.VMStartException;

/**
 * Uses the Sun command line launcher to setup a new debug VM
 * that executes the given JUnit test method.
 * 
 * @author jacek.ratzinger
 *
 */
public class JUnitTestMethodRunner extends TestMethodRunner {

	/* (non-Javadoc)
	 * @see net.sf.jsequnit.diagram.TestMethodRunner#setupDebugVM(java.lang.String)
	 */
	@Override
	protected VirtualMachine setupDebugVM(String qualifiedTestMethod, String testExecutionClasspath) {
		LaunchingConnector sunCommandLineLauncher = getSunCommandLineLauncher();
		
		Map<String, Argument> launchArguments = 
				getConnectorArguments(sunCommandLineLauncher, qualifiedTestMethod, testExecutionClasspath);
		
        VirtualMachine virtualMachine;
		try {
			virtualMachine = sunCommandLineLauncher.launch(launchArguments);
		} catch (IllegalConnectorArgumentsException icae) {
			throw new RuntimeException("test launch of " + qualifiedTestMethod + " failed: " + icae.getMessage(), icae);
		} catch (VMStartException ve) {
			throw new RuntimeException("test launch of " + qualifiedTestMethod + " failed: " + ve.getMessage(), ve);
		} catch (IOException ioe) {
			throw new RuntimeException("test launch of " + qualifiedTestMethod + " failed: " + ioe.getMessage(), ioe);
		}
		return virtualMachine;
	}
		
	private Map<String, Argument> getConnectorArguments(
			LaunchingConnector connector, 
			String testMethod, 
			String testExecutionClasspath) {
		Map<String, Argument> launchArguments = connector.defaultArguments();
		StringArgument mainOption = (StringArgument) launchArguments.get("main");
		mainOption.setValue(SingleTestMethodJUnit.class.getCanonicalName() + " " + testMethod);
		StringArgument options = (StringArgument)launchArguments.get("options");
		options.setValue(options.value() + "-classpath \"" + testExecutionClasspath + "\"");
		return launchArguments;
	}

}
