package net.sf.jsequnit.diagram;

import java.util.List;

import com.sun.jdi.Bootstrap;
import com.sun.jdi.VirtualMachine;
import com.sun.jdi.connect.AttachingConnector;
import com.sun.jdi.connect.LaunchingConnector;
import com.sun.tools.jdi.SocketAttachingConnector;
import com.sun.tools.jdi.SunCommandLineLauncher;

/**
 * Abstract class executing a given method in a separate Java virtual machine.
 * 
 * It implements the design pattern "template method",
 * where subclasses have to provide the debug VM.
 * 
 * @author RatzinJ
 *
 */
public abstract class TestMethodRunner {
	
	abstract protected VirtualMachine setupDebugVM(String qualifiedTestMethod, String testExecutionClasspath);
	
	/**
	 * Setup a new Java virtual machine that is connected for debugging purposes.
	 * 
	 * @param qualifiedTestMethod
	 *            The fully qualified name of a test method that is executed
	 *            in the target virtual machine.
	 * @param testExecutionClasspath
	 *            The classpath used to execute the qualifiedTestMethod
	 * @return The Java VM ready to execute the given method.
	 */
	public VirtualMachine getDebugVm(String qualifiedTestMethod, String testExecutionClasspath) {
		VirtualMachine vm = setupDebugVM(qualifiedTestMethod, testExecutionClasspath);
		return vm;
	}

	/**
	 * Return the Sun VM Launcher
	 * that is capable to execute a Java program from command line before connecting to it.
	 * 
	 * @return LaunchingConnector of type {@code SunCommandLineLauncher} 
	 */
	protected LaunchingConnector getSunCommandLineLauncher() {
		List<LaunchingConnector> launchingConnectors = Bootstrap.virtualMachineManager().launchingConnectors();
		for (LaunchingConnector launchingConnector : launchingConnectors) {
			if (launchingConnector instanceof SunCommandLineLauncher) {
				return launchingConnector;
			}
		}
		return null;
	}
	
	/**
	 * Returns the Socket Launcher
	 * that is capable to connect to a running VM for debugging.
	 * 
	 * @return AttachingConnector of type {@code SocketAttachingConnector}
	 */
	protected AttachingConnector getSocketAttachingConnector()
    {
        List<AttachingConnector> attachingConnectors = Bootstrap.virtualMachineManager().attachingConnectors();
        for (AttachingConnector attachingConnector : attachingConnectors) {
			if (attachingConnector instanceof SocketAttachingConnector) {
				return attachingConnector;
			}
		}
        return null;
    }

}