package net.sf.jsequnit.diagram;

/**
 * A factory for test method runners to allow other the test method runners
 * and test framework additionally to the default JUnit.
 * 
 * @author jacek.ratzinger
 *
 */
class TestMethodRunnerFactory {
	
	private static final Class<?> DEFAULT_RUNNER = JUnitTestMethodRunner.class;
	private static Class<?> testMethodRunnerClass = DEFAULT_RUNNER;

	/**
	 * Creates a new instance of a {@code TestMethodRunner},
	 * where the type is defined by the class instance passed to this factory.
	 * 
	 * @return A new instance of {@code TestMethodRunner}
	 */
	public static TestMethodRunner newTestMethodRunner() {
		try {
			return (TestMethodRunner) testMethodRunnerClass.newInstance();
		} catch (InstantiationException e) {
			throw new RuntimeException("could not create new instance: " + testMethodRunnerClass.getName());
		} catch (IllegalAccessException e) {
			throw new RuntimeException("could not create new instance: " + testMethodRunnerClass.getName());
		}
	}
	
	/**
	 * The provided {@code Class} instance is used to create new {@code TestMethodRunners}
	 * 
	 * @param testMethodRunner
	 *            Has to be a subclass of {@code TestMethodRunner}
	 */
	public static void setTestMethodRunnerPrototypeClass(Class<?> testMethodRunner) {
		testMethodRunnerClass = testMethodRunner;
	}

}
