/**
 * 
 */
package net.sf.jsequnit.javadoc;

import com.sun.javadoc.ClassDoc;
import com.sun.javadoc.PackageDoc;
import com.sun.javadoc.RootDoc;
import com.sun.javadoc.SeeTag;
import com.sun.javadoc.SourcePosition;
import com.sun.javadoc.Tag;

/**
 * @author jacek.ratzinger
 *
 * This class allows adding additional options.
 */
class WrappedRootDoc implements RootDoc {
	
	private final RootDoc originalRootDoc;
	
	private final String[][] additionalOptions;

	public WrappedRootDoc(RootDoc rootDoc, String[][] additionalOptions) {
		this.originalRootDoc = rootDoc;
		this.additionalOptions = additionalOptions;
	}
	
	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#options()
	 */
	public String[][] options() {
		String[][] originalOptions = originalRootDoc.options();
		String[][] allOptions = new String[originalOptions.length + additionalOptions.length][];
		for (int i = 0; i < originalOptions.length; i++) {
			String[] option = originalOptions[i];
			allOptions[i] = option;
		}
		for (int i = 0; i < additionalOptions.length; i++) {
			String[] option = additionalOptions[i];
			allOptions[i + originalOptions.length] = option;
		}
		return allOptions;
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#commentText()
	 */
	public String commentText() {
		return originalRootDoc.commentText();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#tags()
	 */
	public Tag[] tags() {
		return originalRootDoc.tags();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#tags(java.lang.String)
	 */
	public Tag[] tags(String tagname) {
		return originalRootDoc.tags(tagname);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#seeTags()
	 */
	public SeeTag[] seeTags() {
		return originalRootDoc.seeTags();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#inlineTags()
	 */
	public Tag[] inlineTags() {
		return originalRootDoc.inlineTags();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#firstSentenceTags()
	 */
	public Tag[] firstSentenceTags() {
		return originalRootDoc.firstSentenceTags();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#getRawCommentText()
	 */
	public String getRawCommentText() {
		return originalRootDoc.getRawCommentText();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#setRawCommentText(java.lang.String)
	 */
	public void setRawCommentText(String rawDocumentation) {
		originalRootDoc.setRawCommentText(rawDocumentation);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#name()
	 */
	public String name() {
		return originalRootDoc.name();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#compareTo(java.lang.Object)
	 */
	public int compareTo(Object obj) {
		return originalRootDoc.compareTo(obj);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isField()
	 */
	public boolean isField() {
		return originalRootDoc.isField();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isEnumConstant()
	 */
	public boolean isEnumConstant() {
		return originalRootDoc.isEnumConstant();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isConstructor()
	 */
	public boolean isConstructor() {
		return originalRootDoc.isConstructor();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isMethod()
	 */
	public boolean isMethod() {
		return originalRootDoc.isMethod();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isAnnotationTypeElement()
	 */
	public boolean isAnnotationTypeElement() {
		return originalRootDoc.isAnnotationTypeElement();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isInterface()
	 */
	public boolean isInterface() {
		return originalRootDoc.isInterface();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isException()
	 */
	public boolean isException() {
		return originalRootDoc.isException();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isError()
	 */
	public boolean isError() {
		return originalRootDoc.isError();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isEnum()
	 */
	public boolean isEnum() {
		return originalRootDoc.isEnum();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isAnnotationType()
	 */
	public boolean isAnnotationType() {
		return originalRootDoc.isAnnotationType();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isOrdinaryClass()
	 */
	public boolean isOrdinaryClass() {
		return originalRootDoc.isOrdinaryClass();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isClass()
	 */
	public boolean isClass() {
		return originalRootDoc.isClass();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#isIncluded()
	 */
	public boolean isIncluded() {
		return originalRootDoc.isIncluded();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.Doc#position()
	 */
	public SourcePosition position() {
		return originalRootDoc.position();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printError(java.lang.String)
	 */
	public void printError(String msg) {
		originalRootDoc.printError(msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printError(com.sun.javadoc.SourcePosition, java.lang.String)
	 */
	public void printError(SourcePosition pos, String msg) {
		originalRootDoc.printWarning(pos, msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printWarning(java.lang.String)
	 */
	public void printWarning(String msg) {
		originalRootDoc.printWarning(msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printWarning(com.sun.javadoc.SourcePosition, java.lang.String)
	 */
	public void printWarning(SourcePosition pos, String msg) {
		originalRootDoc.printWarning(pos, msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printNotice(java.lang.String)
	 */
	public void printNotice(String msg) {
		originalRootDoc.printNotice(msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.DocErrorReporter#printNotice(com.sun.javadoc.SourcePosition, java.lang.String)
	 */
	public void printNotice(SourcePosition pos, String msg) {
		originalRootDoc.printNotice(pos, msg);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#specifiedPackages()
	 */
	public PackageDoc[] specifiedPackages() {
		return originalRootDoc.specifiedPackages();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#specifiedClasses()
	 */
	public ClassDoc[] specifiedClasses() {
		return originalRootDoc.specifiedClasses();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#classes()
	 */
	public ClassDoc[] classes() {
		return originalRootDoc.classes();
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#packageNamed(java.lang.String)
	 */
	public PackageDoc packageNamed(String name) {
		return originalRootDoc.packageNamed(name);
	}

	/* (non-Javadoc)
	 * @see com.sun.javadoc.RootDoc#classNamed(java.lang.String)
	 */
	public ClassDoc classNamed(String qualifiedName) {
		return originalRootDoc.classNamed(qualifiedName);
	}

}
